package cz.muni.fi.pa165.common;

import jakarta.persistence.AttributeConverter;
import jakarta.persistence.Converter;

import java.util.Arrays;
import java.util.List;

@Converter
public class StringListConverter implements AttributeConverter<List<String>, String> {

    private static final String DELIMITER = ",";

    /**
     * Converts a List of Strings into a single string for storage in the database.
     * The individual strings are separated by a delimiter.
     *
     * @param list the List of Strings to be converted
     * @return a String containing all the individual strings separated by the delimiter
     */
    @Override
    public String convertToDatabaseColumn(List<String> list) {
        return String.join(DELIMITER, list);
    }

    /**
     * Converts a single string stored in the database into a List of Strings.
     * The string is split at the delimiter to retrieve the individual strings.
     *
     * @param joined the string to be split
     * @return a List of Strings containing the individual strings
     */
    @Override
    public List<String> convertToEntityAttribute(String joined) {
        return Arrays.asList(joined.split(DELIMITER));
    }
}