package cz.muni.fi.pa165.movie;

import cz.muni.fi.pa165.common.BaseObject;
import cz.muni.fi.pa165.common.StringListConverter;
import cz.muni.fi.pa165.image.Image;
import jakarta.persistence.*;
import lombok.*;

import java.util.ArrayList;
import java.util.List;

@Getter
@Setter
@Builder
@EqualsAndHashCode(callSuper = false)
@NoArgsConstructor
@AllArgsConstructor
@Entity
public class Movie extends BaseObject {

    @Column(nullable = false)
    private String title;

    private String description;

    @Column(nullable = false)
    private String director;

    @Convert(converter = StringListConverter.class)
    private List<String> actors = new ArrayList<>();

    @ElementCollection(targetClass = GenreEnum.class)
    @Enumerated(EnumType.STRING)
    private List<GenreEnum> genres = new ArrayList<>();

    @OneToMany(mappedBy = "movieId", cascade = CascadeType.ALL)
    private List<Image> images = new ArrayList<>();

    @PrePersist @PostUpdate
    private void beforePersist() {
        for (Image image : images) {
            image.setMovie(this);
        }
    }
}
