import requests
import json

movies_url = "http://localhost:8090/movies"


def setup_movies(auth_header):
    print("------ setting up movies -------")

    image = {"caption": "Cover image", "stringData": "someBase64String"}

    create_movie("The Godfather", "A classic crime drama", "Francis Ford Coppola", ["SCIFI", "DRAMA"],
                 ["Marlon Brando", "Al Pacino", "James Caan"], [image], auth_header)
    create_movie("The Godfather: Part II", "A sequel to the classic crime drama", "Francis Ford Coppola",
                 ["SCIFI", "DRAMA"], ["Al Pacino", "Robert De Niro", "Robert Duvall"], [image], auth_header)
    create_movie("Inception", "A mind-bending thriller", "Christopher Nolan", ["ACTION", "SCIFI", "THRILLER"],
                 ["Leonardo DiCaprio", "Joseph Gordon-Levitt", "Ellen Page"], [image], auth_header)
    create_movie("Pulp Fiction", "A classic crime movie", "Quentin Tarantino", ["SCIFI", "DRAMA"],
                 ["John Travolta", "Samuel L. Jackson", "Uma Thurman"], [image], auth_header)
    create_movie("The Silence of the Lambs", "A psychological thriller", "Jonathan Demme",
                 ["SCIFI", "DRAMA", "THRILLER"], ["Jodie Foster", "Anthony Hopkins", "Lawrence A. Bonney"], [image], auth_header)
    create_movie("The Lord of the Rings: The Fellowship of the Ring", "An epic fantasy adventure", "Peter Jackson",
                 ["FANTASY", "ACTION"], ["Elijah Wood", "Ian McKellen", "Viggo Mortensen"], [image], auth_header)
    create_movie("The Avengers", "A superhero team-up movie", "Joss Whedon", ["ACTION", "SCIFI"],
                 ["Robert Downey Jr.", "Chris Evans", "Mark Ruffalo"], [image], auth_header)
    create_movie("The Matrix", "A sci-fi action movie", "The Wachowskis", ["ACTION", "SCIFI"],
                 ["Keanu Reeves", "Laurence Fishburne", "Carrie-Anne Moss"], [image], auth_header)
    
    movie1 = get_movie_by_title("The Godfather", auth_header)
    movie2 = get_movie_by_title("The Godfather: Part II", auth_header)
    movie3 = get_movie_by_title("Inception", auth_header)
    movie4 = get_movie_by_title("Pulp Fiction", auth_header)
    movie5 = get_movie_by_title("The Silence of the Lambs", auth_header)
    movie6 = get_movie_by_title("The Lord of the Rings: The Fellowship of the Ring", auth_header)
    movie7 = get_movie_by_title("The Avengers", auth_header)
    movie8 = get_movie_by_title("The Matrix", auth_header)
    
    return [movie1, movie2, movie3, movie4, movie5, movie6, movie7, movie8]


def create_movie(title, description, director, genres, actors, images, auth_header):
    json_data = {"title": title,
                 "description": description,
                 "director": director,
                 "genres": genres,
                 "actors": actors,
                 "images": images
                 }
    response = requests.post(movies_url, json=json_data, headers=auth_header)
    if response.status_code == 200:
        print(f"Movie {title} created.")
    else:
        print(f"Error while creating movie {title}.")


def get_movie_by_title(title, auth_header):
    response = requests.get(f"{movies_url}/title/{title}", headers=auth_header)
    if response.status_code == 200:
        print(f"Retrieved movie {title}.")
        return response.json()
    else:
        print(f"Error while retrieving movie {title}.")
        return None


def delete_all_movies(auth_header):
    response = requests.delete(movies_url, headers=auth_header)
    if response.status_code == 200:
        print("Deleted all movies.")
    else:
        print("Error while deleting all movies")
