import requests
import json
import random
import threading

ratings_url = "http://localhost:8090/ratings"


def setup_ratings(users, movies, auth_header):
    print("------ setting up ratings -------")
    categories = ["FUN", "CAST", "PLOT", "SPECIAL_EFFECTS", "OVERALL"]

    threads = []
    for i in range(100):
        category = random.choice(categories)
        rating = random.randint(1, 10)
        user = random.choice(users)
        movie = random.choice(movies)

        t = threading.Thread(target=create_rating, args=(category, rating, user, movie, auth_header))
        threads.append(t)

    for t in threads:
        t.start()

    for t in threads:
        t.join()


def create_rating(category, rating, user, movie, auth_header):
    json_data = {"category": category,
                 "rating": rating,
                 "userId": user["id"],
                 "movieId": movie["id"]
                 }
    response = requests.post(ratings_url, json=json_data, headers=auth_header)
    if response.status_code == 200:
        print(f"Rating {rating} in category {category} for movie {movie['title']} created.")
    else:
        print(f"Error while creating rating {rating} in category {category} for movie {movie['title']}.")


def delete_all_ratings(auth_header):
    response = requests.delete(ratings_url, headers=auth_header)
    if response.status_code == 200:
        print("Deleted all ratings.")
    else:
        print("Error while deleting all ratings")
